@@ -110,6 +110,8 @@ class MOSlurmSpawner(SlurmSpawner):
         "exclusive": lambda v: v == "true",
         "ngpus": int,
         "jupyterlab": lambda v: v == "true",
+        "options": lambda v: v.strip(),
+        "output": lambda v: v == "true",
     }
 
     _RUNTIME_REGEXP = re.compile(
@@ -154,6 +156,9 @@ class MOSlurmSpawner(SlurmSpawner):
         ):
             raise AssertionError("Error in number of GPUs")
 
+        if "options" in options and "\n" in options["options"]:
+            raise AssertionError("Error in extra options")
+
     def options_from_form(self, formdata: Dict[str, List[str]]) -> Dict[str, str]:
         """Parse the form and add options to the SLURM job script"""
         # Convert expected input from List[str] to appropriate type
